=========
Edit Mesh
=========

Edit mesh commands are used to edit an orphan mesh part or part instance or an Abaqus native mesh.


Classes
-------

Edit mesh features of Assembly
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.EditMesh.MeshEditAssembly.MeshEditAssembly
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

Edit mesh features of Part
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.EditMesh.MeshEditPart.MeshEditPart
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

MeshEditOptions
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.EditMesh.MeshEditOptions.MeshEditOptions
    :members:
    :special-members: __init__